@@ -4,20 +4,21 @@
  *
  * This example program implements a websocket
  *
- * Copyright 2017 Nicolas Mora <mail@babelouest.org>
+ * Copyright 2017-2022 Nicolas Mora <mail@babelouest.org>
  *
  * License MIT
  *
  */
 
-#include <string.h>
-#include <unistd.h>
-#include <inttypes.h>
-#include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/types.h>
 
+#include <inttypes.h>
+#include <string.h>
 #include <ulfius.h>
-#include <u_example.h>
+#include <unistd.h>
+
+#include "u_example.h"
 
 #define PORT "9275"
 #define PREFIX_WEBSOCKET "/websocket"
